{% extends 'ui/layout.html' %}
{% load i18n %}

{% block content %}
    <div class="columns is-desktop m-0">
        <div class="column p-0 is-8-desktop">
            <div class="form-box">
                {% include 'ui/partials/form_errors.html' with show_field_errors=True %}
                {% block form %}{% endblock %}
            </div>
        </div>
        <div class="column is-4">
            <nav class="">
                {% block info_panel %}
                {% endblock %}
            </nav>
        </div>
    </div>


{#    <div class="columns is-desktop m-0">#}
{#        <div class="column p-0 is-8-desktop">#}
{#            <div>#}
{#                {% include 'ui/partials/form_errors.html' with show_field_errors=True %}#}
{#                {% block form %}{% endblock %}#}
{#            </div>#}
{#        </div>#}
{#        <div class="column is-4"></div>#}
{#    </div>#}
{% endblock %}
